/*
export function someAction (context) {
}
*/
import firebase from "firebase/app";

import { firestoreAction } from "vuexfire";

export const setProjectsRef = firestoreAction(
  ({ bindFirestoreRef, commit }, ref) => {
    return bindFirestoreRef("projects", ref);
  }
);

export const setCategoryRef = firestoreAction(
  ({ bindFirestoreRef, commit }, ref) => {
    return bindFirestoreRef("category", ref);
  }
);

export function loadAllProjects({ state, dispatch }) {
  const db = firebase.firestore();

  var ref = db.collection("projects").orderBy("created", "desc");

  dispatch("setProjectsRef", ref);
}

export function loadCategory({ state, dispatch }, category_id) {
  const db = firebase.firestore();

  var projects_ref = db
    .collection("projects")
    .where("category_id", "==", category_id);

  var cat_ref = db.collection("categories").doc(category_id);

  dispatch("setProjectsRef", projects_ref);
  dispatch("setCategoryRef", cat_ref);
}

export const loadLatestProjects = firestoreAction(({ bindFirestoreRef }) => {
  const db = firebase.firestore();
  const ref = db
    .collection("projects")
    .orderBy("created", "desc")
    .limit(6);
  return bindFirestoreRef("latestProjects", ref);
});

export const loadFeaturedProjects = firestoreAction(({ bindFirestoreRef }) => {
  const db = firebase.firestore();
  const ref = db
    .collection("projects")
    .where("featured", "==", true)
    .orderBy("created", "desc")
    .limit(6);
  return bindFirestoreRef("featuredProjects", ref);
  // dispatch("setFeaturedProjectsRef", ref);
});

export const loadPopularProjects = firestoreAction(({ bindFirestoreRef }) => {
  const db = firebase.firestore();
  const ref = db
    .collection("projects")
    .orderBy("downloadsCount", "desc")
    .limit(6);
  return bindFirestoreRef("popularProjects", ref);
  // dispatch("setFeaturedProjectsRef", ref);
});

export const loadProject = firestoreAction(
  ({ bindFirestoreRef, state }, key) => {
    const db = firebase.firestore();

    const ref = db.collection("projects").doc(key);
    return Promise.all([
      bindFirestoreRef("selectedProject", ref),
      bindFirestoreRef("selectedProjectPhotos", ref.collection("photos")),
      bindFirestoreRef("selectedProjectFiles", ref.collection("files")),
      bindFirestoreRef("selectedProjectComments", ref.collection("comments"))
    ]).then(() => {
      bindFirestoreRef(
        "relatedProjects",
        db
          .collection("projects")
          .where("category", "==", state.selectedProject["category"])
          .orderBy("downloadsCount", "desc")
          .limit(6)
      );
    });
  }
);
